==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=cs
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Zadejte adresu URL svého webu', # MODIF
	'form_pet_aucune_signature' => 'Tomuto kódu neodpovídá žádný podpis...', # MODIF
	'form_pet_confirmation' => 'Potvrďte svůj podpis:',
	'form_pet_deja_signe' => 'Tento text jste již podepsali.',
	'form_pet_envoi_mail_confirmation' => 'Byla vám zaslána elektronická zpráva s potvrzením. Platnost podpisu ověříte na adrese URL, která je v této zprávě uvedena.', # MODIF
	'form_pet_mail_confirmation' => 'Dobrý den,

Rozhodli jste se podepsat petici:
@titre@.

Uvedli jste následující údaje:
    Jméno: @nom_email@
    Web: @nom_site@ - @url_site@
    @message@

DŮLEŽITÉ UPOZORNĚNÍ...
Platnost svého podpisu potvrdíte přechodem
na níže uvedenou adresu (jinak bude váš požadavek
zamítnut):

    @url@


Děkujeme vám za účast
',
	'form_pet_nom_site2' => 'Název vašeho webu', # MODIF
	'form_pet_probleme_technique' => 'Z technických důvodů nelze momentálně podepisovat.',
	'form_pet_signature_validee' => 'Váš podpis je platný. Děkujeme vám!',
	'form_pet_site_deja_enregistre' => 'Tento web je již zaregistrován',
	'form_pet_url_invalide' => 'Zadali jste neplatnou adresu URL.',
	'form_pet_votre_email' => 'Nová elektronická adresa',
	'form_pet_votre_nom' => 'Jméno nebo přezdívka (alias)', # MODIF
	'form_pet_votre_site' => 'Máte-li web, můžete dále zadat jeho adresu',

	// I
	'info_adresse_email' => 'ELEKTRONICKÁ ADRESA:',
	'info_site_web' => 'WEB:',

	// L
	'lien_reponse_article' => 'Odpověď na článek'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=cs
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Zapnout petici',
	'bouton_radio_pas_petition' => 'Bez petice',
	'bouton_radio_petition_activee' => 'Petice zapnuta',
	'bouton_radio_supprimer_petition' => 'Odstranit petici',

	// F
	'form_pet_adresse_site' => 'Zadejte adresu URL svého webu', # MODIF
	'form_pet_aucune_signature' => 'Tomuto kódu neodpovídá žádný podpis...', # MODIF
	'form_pet_confirmation' => 'Potvrďte svůj podpis:',
	'form_pet_deja_signe' => 'Tento text jste již podepsali.',
	'form_pet_envoi_mail_confirmation' => 'Byla vám zaslána elektronická zpráva s potvrzením. Platnost podpisu ověříte na adrese URL, která je v této zprávě uvedena.', # MODIF
	'form_pet_mail_confirmation' => 'Dobrý den,

Rozhodli jste se podepsat petici:
@titre@.

Uvedli jste následující údaje:
    Jméno: @nom_email@
    Web: @nom_site@ - @url_site@
    @message@

DŮLEŽITÉ UPOZORNĚNÍ...
Platnost svého podpisu potvrdíte přechodem
na níže uvedenou adresu (jinak bude váš požadavek
zamítnut):

    @url@


Děkujeme vám za účast
',
	'form_pet_nom_site2' => 'Název vašeho webu', # MODIF
	'form_pet_probleme_technique' => 'Z technických důvodů nelze momentálně podepisovat.',
	'form_pet_signature_validee' => 'Váš podpis je platný. Děkujeme vám!',
	'form_pet_site_deja_enregistre' => 'Tento web je již zaregistrován',
	'form_pet_url_invalide' => 'Zadali jste neplatnou adresu URL.',
	'form_pet_votre_email' => 'Nová elektronická adresa',
	'form_pet_votre_nom' => 'Jméno nebo přezdívka (alias)', # MODIF
	'form_pet_votre_site' => 'Máte-li web, můžete dále zadat jeho adresu',

	// I
	'info_adresse_email' => 'ELEKTRONICKÁ ADRESA:',
	'info_site_web' => 'WEB:',

	// L
	'lien_reponse_article' => 'Odpověď na článek'
);

?>
